from pythonConsoleConfigs.Font import Color as c
from pythonConsoleConfigs.Loading.helper import run


class Box:
    def __init__(self, duration, size, color=c.WHITE, reverse=False):
        self.seconds = duration
        self.color = color
        self.reverse = reverse
        self.__emptyBox__ = "□"
        self.__fullBox__ = "■"
        self.__rate__(size)

    def __rate__(self, size):
        animation = []
        accumulator = size - 1
        if self.reverse:
            self.__emptyBox__, self.__fullBox__ = self.__fullBox__, self.__emptyBox__

        for r in range(1, size + 1):
            animation.append(self.__fullBox__ * r + self.__emptyBox__ * accumulator)
            accumulator -= 1
        self.animation = animation

    def loading(self):
        run(self.color, self.animation, self.seconds)



from pythonConsoleConfigs.Font import Color as c
from pythonConsoleConfigs.Loading.helper import run


class Percentage:
    def __init__(self, duration, rate, color=c.WHITE):
        self.seconds = duration
        self.color = color
        self.__rate__(rate)

    def __rate__(self, rate):
        if 100 % rate == 0:
            animation = []
            for r in range(1, int(100 / rate) + 1):
                animation.append((str(r * rate) + "%"))
            self.animation = animation

    def loading(self):
        try:
            run(self.color, self.animation, self.seconds)
        except AttributeError:
            raise Exception("Error, rate must be divisor of 100!")



class Style:
    BOLD = '\33[1m'
    ITALIC = '\33[3m'
    URL = '\33[4m'
    BLINK = '\33[5m'
    BLINK2 = '\33[6m'
    SELECTED = '\33[7m'
    __RESET = '\33[0m'

    def reset(self):
        print(self.__RESET, end="")



import sys
import time

from pythonConsoleConfigs.Font import Style as s


def run(color, animation, duration):
    print(color, end="")
    for i in range(len(animation)):
        time.sleep(duration)
        sys.stdout.write("\r" + animation[i % len(animation)])
        sys.stdout.flush()
    s().reset()



from setuptools import setup, find_packages
from pathlib import Path

long_description = Path("README.md").read_text()

setup(
    name='pythonConsoleConfigs',
    description="Python Console Configuration",
    long_description=long_description,
    long_description_content_type='text/markdown',
    version='0.9.4',
    license='Apache License',
    author="Stefanos Grigori",
    author_email='gregorystefanos@gmail.com',
    packages=find_packages(),
    url='https://github.com/StefanosGregory/PythonConsoleConfig',
    keywords=['Python', 'Console', 'Configuration', 'Font', 'Color', 'Highlight', 'Style', 'Loading', 'Load']
)



from Font import Color, Style, Highlight
from Loading import Box, Percentage


def printTesting(msg, color, reset=True):
    print(f'{color}{msg}')
    if reset:
        Style().reset()


if __name__ == '__main__':
    printTesting('This is a test of Python Console Configuration Library', Color.MAGENTA)
    printTesting('This is a test of Python Console Configuration Library', Style.BLINK)
    printTesting('This is a test of Python Console Configuration Library', Highlight.BLUE)
    printTesting('This is a test of Python Console Configuration Library', Color.CYAN)
    printTesting('This is a test of Python Console Configuration Library', Color.LIGHT_CYAN)
    printTesting('This is a test of Python Console Configuration Library', Color.LIGHT_RED)
    print("TEST OF RESET")

    Box(duration=1, size=15, color=Color.BLUE, reverse=True).loading()
    Percentage(duration=1, rate=10, color=Color.RED).loading()
